@@ -7,6 +7,7 @@ import os
 
 	
 dir_path = os.path.abspath(os.curdir)
+extra_tags={}
 config = AutoConfig(search_path=dir_path)
 
 logger = logging.getLogger()
@@ -18,9 +19,9 @@ con.setLevel(logging.INFO)
 formatter = logging.Formatter('%(message)s')
 con.setFormatter(formatter)
 logger.addHandler(con)
-tags={}
+
 def set_tags(key,value):
-        tags[key]=value
+        extra_tags[key]=value
 def merge_two_dicts(x, y):
         z = x.copy()   # start with x's keys and values
         z.update(y)    # modifies z with y's keys and values & returns None
@@ -40,7 +41,7 @@ def _log(msg, application, level,execution_time, user_id, extra_data):
             "extra_data": extra_data,
             "timestamp": now
         }
-        data=merge_two_dicts(original_data, tags)
+        data=merge_two_dicts(original_data, extra_tags)
 
         handler = logging.FileHandler(config('DIR')+now+'.log')
         handler.setLevel(logging.INFO)
